@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -30,13 +30,13 @@ void SieveEditorSavePasswordJob::start()
 {
     if (!canStart()) {
         if (mName.isEmpty()) {
-            qCWarning(SIEVEEDITOR_LOG) << "Error missing mName";
+            qCWarning(SIEVEEDITOR_LOG) << "Error missing name info";
         }
         if (mKey.isEmpty()) {
-            qCWarning(SIEVEEDITOR_LOG) << "Error missing mKey";
+            qCWarning(SIEVEEDITOR_LOG) << "Error missing key";
         }
         if (mPassword.isEmpty()) {
-            qCWarning(SIEVEEDITOR_LOG) << "Error missing mName";
+            qCWarning(SIEVEEDITOR_LOG) << "Error missing password";
         }
         deleteLater();
         return;
